/*  fitsjd.c   */
/*  Jure Skvarc, March 1999  */
/*  A program which calculates the Julian day of middle of  */
/*  exposure from a FITS header and writes it to the standard output  */
#include <stdio.h>
#include <getopt.h>
#include <fitsio.h>

#include "functs.h"

int
main(int argc, char *argv[])

{
  int opt;
  int i, j;
  int errnum;
  int dojd = 0, dowcs = 0;
  char *errors[ERROR_MAX];
  int year, month, day, hour, minute;
  float second;
  FITSFILE fitsfile;

  while ((opt = getopt(argc, argv, "jw")) != -1) {
    switch(opt) {
    case 'j':
      /*  Print out Julian day  */
      dojd = 1;
      break;
    case 'w':
      /*  Print out WCS keywords  */
      dowcs = 1;
      break;
    case '?':
      switch(optopt) {
      default:
	fprintf(stderr, "Unknown option -%c ignored!\n", optopt);
	break;
      }
      break;
    }
  }

  for (j = optind; j < argc; j++) {
    errnum = read_fits(argv[j], &fitsfile, errors);
    if (errnum > 0) {
      for (i = 0; i < errnum; i++) {
	fprintf(stderr, "%s\n", errors[i]);
      }
      exit(1);
    }
    /*  If possible, calculate time and date of mid-exposure  */
    calculate_midexposure(&fitsfile, &year, &month, &day, &hour, &minute, &second);
    /*  Also calculate the Julian day  */
    fitsfile.jd = julian_day(year, month, day + 
			     (hour + (minute + second / 60.0) / 60.0) / 24.0);

    if (dowcs && !fitsfile.wcs) {
      fprintf(stderr, "No WCS keywords!\n");
    }
    printf("%s ", argv[j]);
    if (dojd) {
      printf("%.8f ", fitsfile.jd);
    }
    if (dowcs) {
      printf("%.8f %.8f %.8f %.8f %.8f %.8f %.8f ",
	     fitsfile.crval1, fitsfile.crval2,
	     fitsfile.crpix1, fitsfile.crpix2,
	     fitsfile.cdelt1, fitsfile.cdelt2,
	     fitsfile.crot);
    }
    printf("%ld %ld ", fitsfile.nax[0], fitsfile.nax[1]);
    printf("\n");
  }    
  return 0;
}
